@@ -117,16 +117,16 @@ def combine(name: str, group_files=None, alpha=0.05, min_cnt_sum=20, filter_id=N
         its = list(filter(lambda x: x[1][0][1] and filter_id.match(x[1][0][1]), its))
     if filter_chr:
         its = list(filter(lambda x: filter_chr.match(x[0]), its))
+
     with Manager() as manager:
         if n_jobs > 1:
-            its = manager.dict(its)
-            stats = manager.dict(stats)
+            its = manager.list(its)
         with Pool(n_jobs) as p:
             f = partial(combine_stats, snvs=its, stats=stats, groups=groups, min_cnt_sum=min_cnt_sum)
             if n_jobs > 1:
                 sz = int(np.ceil(len(its) / n_jobs))
                 inds = batched(range(len(its)), sz)
-                iterate = p.imap(f, inds)
+                iterate = p.map(f, inds, chunksize=1)
             else:
                 iterate = map(f, [list(range(len(its)))])
             for pvals, es, ks in iterate:
